Module: PgCron::Adapters

Defined in:
lib/pg_cron/adapters/postgres.rb,
lib/pg_cron/adapters/postgres/jobs.rb,
lib/pg_cron/adapters/postgres/connection.rb,
lib/pg_cron/adapters/postgres/query_executor.rb

Overview

Database adapters.

Ships with a Postgres adapter only — pg_cron is a Postgres extension, so there is no other engine to support — but the interface is the same one F(x) defines, so an alternative could be substituted the same way.

Defined Under Namespace

Classes: Postgres